<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Sessions Documentation

- **[agent-session-files.md](agent-session-files.md)** — reading or extracting data from agent session files, working with agent subprocesses in Claude sessions, implementing session log parsing
- **[agent-type-extraction.md](agent-type-extraction.md)** — extracting agent type from session, finding subagent_type for agent sessions, correlating agent sessions to their Task invocation, displaying agent metadata in session show
- **[context-analysis.md](context-analysis.md)** — analyzing context consumption, debugging context window blowout, understanding why session ran out of context
- **[context-optimization.md](context-optimization.md)** — analyzing session efficiency, troubleshooting context limits, reducing context waste
- **[discovery-fallback.md](discovery-fallback.md)** — implementing session analysis workflows, handling missing session files, enumerating available sessions
- **[jsonl-schema-reference.md](jsonl-schema-reference.md)** — parsing Claude Code session files, understanding JSONL entry types, extracting data from session logs, building tools that process session transcripts, debugging session parsing issues
- **[layout.md](layout.md)** — working with session logs, parsing session logs, understanding ~/.claude/projects/ structure, debugging session lookup issues, implementing features that depend on project directory resolution
- **[lifecycle.md](lifecycle.md)** — working with Claude Code sessions, implementing learn workflows, accessing planning session files
- **[parallel-session-awareness.md](parallel-session-awareness.md)** — working with session-specific data, implementing session-scoped features, accessing plans, scratch files, or session metadata
- **[preprocessing.md](preprocessing.md)** — preprocessing Claude Code session logs for analysis
- **[raw-session-processing.md](raw-session-processing.md)** — processing issues with erk-raw-session label, extracting documentation from landed PR sessions, understanding raw session issue format
- **[session-hierarchy.md](session-hierarchy.md)** — understanding Claude Code session structure, working with parent and agent sessions, finding session files on disk, correlating agent logs to parent sessions, implementing session-scoped file discovery
- **[tools.md](tools.md)** — finding session logs, inspecting agent execution, debugging session issues
